caellion-python-commons: caellion.pycommons.hashing.file_hashing.NotDoneYetException Class Reference

caellion-python-commons

caellion.pycommons.hashing.file_hashing.NotDoneYetException Class Reference

This exception is raised when a hash was requested from a FileHasher that has not hashed any file yet. More...

Inheritance diagram for caellion.pycommons.hashing.file_hashing.NotDoneYetException:

## Detailed Description

This exception is raised when a hash was requested from a FileHasher that has not hashed any file yet.

Definition at line 24 of file file_hashing.py.

The documentation for this class was generated from the following file:

- caellion/pycommons/hashing/file_hashing.py